pub enum Rule {
Children(f32),
Parent(f32),
Fixed(f32),
}Expand description
A constraint on an axis of containers.
Variants
Children(f32)
The container’s size is equal to the total size of all its children
times f32. (may not be below 1).
The computed size of children depends on the container’s main axis.
For a Flow::Horizontal container:
- The horizontal size of children is the sum of the width of every children.
- The vertical size of children is that of the tallest child.
The reverse is true for Flow::Vertical.
IMPORTANT: When
Rule::Childrenis used on a container’s size, none of its children may depend on its parent size. It would lead to a circular dependency.
Parent(f32)
The container’s size is equal to its parent’s size times f32.
(may not be above 1)
IMPORTANT: this is the size of of the container within margin. ie: it is the possible space the children can occupy, the total size is substracted that of the margins.
Fixed(f32)
The container’s size is equal to precisely f32 pixels.